Coverage report

# Coverage report: 98%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 323 | 8 | 0 | 98%
markupmirror | 17 | 0 | 0 | 100%
markupmirror.exceptions | 2 | 0 | 0 | 100%
markupmirror.feincms | 4 | 0 | 0 | 100%
markupmirror.feincms.models | 18 | 0 | 0 | 100%
markupmirror.fields | 99 | 2 | 0 | 98%
markupmirror.markup | 6 | 0 | 0 | 100%
markupmirror.markup.base | 39 | 0 | 0 | 100%
markupmirror.markup.html | 8 | 0 | 0 | 100%
markupmirror.markup.markdown_ | 22 | 2 | 0 | 91%
markupmirror.markup.plaintext | 12 | 0 | 0 | 100%
markupmirror.markup.restructuredtext | 18 | 2 | 0 | 89%
markupmirror.markup.textile_ | 18 | 2 | 0 | 89%
markupmirror.models | 0 | 0 | 0 | 100%
markupmirror.settings | 9 | 0 | 0 | 100%
markupmirror.urls | 7 | 0 | 0 | 100%
markupmirror.views | 10 | 0 | 0 | 100%
markupmirror.widgets | 34 | 0 | 0 | 100%